import AMapLoader from '@amap/amap-jsapi-loader';

//栅格生成
export function drawGe( gsize, paths, polygons, map) {
    // 拿到四角坐标
    let bounds = map.getBounds();
    console.log(bounds.northEast.toString());
    console.log(bounds.southWest.toString());

    let mSWLat = bounds.southWest.getLat(); //西南角的纬度 num 下
    let mSWLng = bounds.southWest.getLng(); //西南角的经度 num 左
    let mNELat = bounds.northEast.getLat(); //东北角的纬度 num 上
    let mNELng = bounds.northEast.getLng(); //东北角的经度 num 右

    let data = [
        new AMap.LngLat(mSWLng, mSWLat), //西南角
        new AMap.LngLat(mSWLng, mNELat), //西北角
        new AMap.LngLat(mNELng, mNELat), //东北角
        new AMap.LngLat(mNELng, mSWLat), //东南角

    ]
    addPolygon(data);

    //划分网格
    //纬度差
    let DeltaLat = mNELat - mSWLat;
    //经度差
    let DeltaLng = mNELng - mSWLng;
    //跨度值
    let spanLat = DeltaLat / gsize.value; //纬度(上下
    let spanLng = DeltaLng / gsize.value; //经度(左右

    //瓦片四角坐标
    //结束后paths会有多少个瓦片的信息（每个瓦片包含四个角经纬坐标
    for (let row = 0; row < gsize.value; row++) {
        for (let col = 0; col < gsize.value; col++) {
            let SWLng = mSWLng + col * spanLng; //西南角经度
            let SWLat = mSWLat + row * spanLat; //西南角纬度
            let NELng = SWLng + spanLng; //东北角经度
            let NELat = SWLat + spanLat; //东北角纬度

            let data = [
                new AMap.LngLat(SWLng, SWLat), //西南角
                new AMap.LngLat(SWLng, NELat), //西北角
                new AMap.LngLat(NELng, NELat), //东北角
                new AMap.LngLat(NELng, SWLat), //东南角
            ];

            addPolygon(data, polygons, map);

            paths.push(data);

        }
    }

}

//单独生成多边形，只是传入参数不一样
export function addPolygon(path, polygons, map) {
    let polygon = new AMap.Polygon({
        path: path,
        fillColor: '#ccebc5',
        strokeOpacity: 1,
        fillOpacity: 0.2,
        strokeColor: '#2b8cbe',
        strokeWeight: 1,
        strokeStyle: 'dashed',
        strokeDasharray: [5, 5],
    });
    polygon.on('click', () => { //触发poi查询
        polygon.setOptions({
            fillOpacity: 0.7,
            fillColor: '#7bccc4'
        });
        poiSearch(polygon);

    })
    polygon.on('mouseout', () => {
        polygon.setOptions({
            fillOpacity: 0.5,
            fillColor: '#ccebc5'

        })
    })

    //设置完成添加到数组
    polygons.push(polygon);

    map.add(polygon);
}

/**
 * 边缘poi
 * @param polygonArr
 * @param key
 * @returns {*}
 */
// 当时遇到一个异步问题，以及打算写成方便调用的形式，就单独拿出来了。但好像没咋用
export function searchByKeyInBounds(polygonArr,key) {
    return AMap.plugin("AMap.PlaceSearch", function () {
        let placeSearch = new AMap.PlaceSearch({
            //city 指定搜索所在城市，支持传入格式有：城市名、citycode 和 adcode
            city: "上海",
        });
        //多边形范围坐标数组

        console.log(polygonArr);

        placeSearch.searchInBounds(key, polygonArr, function (status, result) {
            console.log(result);
            let pois = 0
            //查询成功时，result 即对应匹配的 POI 信息
            if (result.info === 'OK') {
                pois = result.poiList.pois;
            }
            return pois
        });
    })
}

// 绘制某个行政区的边缘
export function drawCity(map) {
    AMap.plugin("AMap.DistrictSearch", function () {
        let district = new AMap.DistrictSearch({
            extensions: "all", //返回行政区边界坐标等具体信息
            level: "province", //设置查询行政区级别为区
        });
        //调整第一个参数即可。
        district.search("梅州市", function (status, result) {
            let bounds = result.districtList[0].boundaries; //获取朝阳区的边界信息
            if (bounds) {
                for (let i = 0; i < bounds.length; i++) {
                    //生成行政区划 polygon
                    let polygon = new AMap.Polygon({
                        map: map, //显示该覆盖物的地图对象
                        strokeWeight: 1, //轮廓线宽度
                        path: bounds[i], //多边形轮廓线的节点坐标数组
                        fillOpacity: 0.7, //多边形填充透明度
                        fillColor: "#CCF3FF", //多边形填充颜色
                        strokeColor: "#CC66CC", //线条颜色
                    });

                }
                map.setFitView(); //将覆盖物调整到合适视野
            }
        });
    });
}